@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 # type: ignore
 
-# Compiled with Coconut version 1.5.0-post_dev74 [Fish License]
+# Compiled with Coconut version 2.0.0-a_dev36 [How Not to Be Seen]
 
 """Built-in Coconut utilities."""
 
@@ -137,6 +137,13 @@ if _coconut_sys.version_info < (3,):
     def xrange(*args):
         """Coconut uses Python 3 'range' instead of Python 2 'xrange'."""
         raise _coconut.NameError("Coconut uses Python 3 'range' instead of Python 2 'xrange'")
+    def _coconut_exec(obj, globals=None, locals=None):
+        """Execute the given source in the context of globals and locals."""
+        if locals is None:
+            locals = _coconut_sys._getframe(1).f_locals if globals is None else globals
+        if globals is None:
+            globals = _coconut_sys._getframe(1).f_globals
+        exec(obj, globals, locals)
     def _coconut_default_breakpointhook(*args, **kwargs):
         hookname = _coconut.os.getenv("PYTHONBREAKPOINT")
         if hookname != "0":
@@ -169,6 +176,7 @@ else:
     from builtins import chr, filter, hex, input, int, map, object, oct, open, print, range, str, zip, filter, reversed, enumerate
     py_chr, py_hex, py_input, py_int, py_map, py_object, py_oct, py_open, py_print, py_range, py_str, py_zip, py_filter, py_reversed, py_enumerate, py_repr = chr, hex, input, int, map, object, oct, open, print, range, str, zip, filter, reversed, enumerate, repr
     _coconut_py_str = str
+    exec("_coconut_exec = exec")
     if _coconut_sys.version_info < (3, 7):
         def _coconut_default_breakpointhook(*args, **kwargs):
             hookname = _coconut.os.getenv("PYTHONBREAKPOINT")
@@ -193,7 +201,7 @@ else:
     else:
         py_breakpoint = breakpoint
 class _coconut(object):
-    import collections, copy, functools, types, itertools, operator, threading, os, warnings, contextlib, traceback, weakref, multiprocessing
+    import collections, copy, functools, types, itertools, operator, threading, os, warnings, contextlib, traceback, weakref, multiprocessing, math
     from multiprocessing import dummy as multiprocessing_dummy
     if _coconut_sys.version_info < (3, 2):
         try:
@@ -227,8 +235,16 @@ class _coconut(object):
     else:
         import typing
     zip_longest = itertools.zip_longest if _coconut_sys.version_info >= (3,) else itertools.izip_longest
-    Ellipsis, NotImplemented, NotImplementedError, Exception, AttributeError, ImportError, IndexError, KeyError, NameError, TypeError, ValueError, StopIteration, RuntimeError, any, bytes, classmethod, dict, enumerate, filter, float, frozenset, getattr, hasattr, hash, id, int, isinstance, issubclass, iter, len, list, locals, map, min, max, next, object, print, property, range, reversed, set, slice, str, sum, super, tuple, type, vars, zip, repr, bytearray = Ellipsis, NotImplemented, NotImplementedError, Exception, AttributeError, ImportError, IndexError, KeyError, NameError, TypeError, ValueError, StopIteration, RuntimeError, any, bytes, classmethod, dict, enumerate, filter, float, frozenset, getattr, hasattr, hash, id, int, isinstance, issubclass, iter, len, list, locals, map, min, max, next, object, print, property, range, reversed, set, slice, str, sum, super, tuple, type, vars, zip, staticmethod(repr), bytearray
-_coconut_sentinel = _coconut.object()
+    try:
+        import numpy
+    except ImportError:
+        class you_need_to_install_numpy(object): pass
+        numpy = you_need_to_install_numpy()
+    else:
+        abc.Sequence.register(numpy.ndarray)
+    abc.Sequence.register(collections.deque)
+    Ellipsis, NotImplemented, NotImplementedError, Exception, AttributeError, ImportError, IndexError, KeyError, NameError, TypeError, ValueError, StopIteration, RuntimeError, all, any, bytes, classmethod, dict, enumerate, filter, float, frozenset, getattr, hasattr, hash, id, int, isinstance, issubclass, iter, len, list, locals, map, min, max, next, object, property, range, reversed, set, slice, str, sum, super, tuple, type, vars, zip, repr, print, bytearray = Ellipsis, NotImplemented, NotImplementedError, Exception, AttributeError, ImportError, IndexError, KeyError, NameError, TypeError, ValueError, StopIteration, RuntimeError, all, any, bytes, classmethod, dict, enumerate, filter, float, frozenset, getattr, hasattr, hash, id, int, isinstance, issubclass, iter, len, list, locals, map, min, max, next, object, property, range, reversed, set, slice, str, sum, super, tuple, type, vars, zip, staticmethod(repr), staticmethod(print), bytearray
+class _coconut_sentinel(object): pass
 class _coconut_base_hashable(object):
     __slots__ = ()
     def __reduce_ex__(self, _):
@@ -241,7 +257,7 @@ class MatchError(_coconut_base_hashable, Exception):
     """Pattern-matching error. Has attributes .pattern, .value, and .message."""
     __slots__ = ("pattern", "value", "_message")
     max_val_repr_len = 500
-    def __init__(self, pattern, value):
+    def __init__(self, pattern=None, value=None):
         self.pattern = pattern
         self.value = value
         self._message = None
@@ -265,8 +281,8 @@ class MatchError(_coconut_base_hashable, Exception):
         return (self.__class__, (self.pattern, self.value))
 class _coconut_tail_call(object):
     __slots__ = ("func", "args", "kwargs")
-    def __init__(self, func, *args, **kwargs):
-        self.func = func
+    def __init__(self, _coconut_func, *args, **kwargs):
+        self.func = _coconut_func
         self.args = args
         self.kwargs = kwargs
 _coconut_tco_func_dict = {}
@@ -296,17 +312,26 @@ def _coconut_tco(func):
             call_func, args, kwargs = result.func, result.args, result.kwargs
     tail_call_optimized_func._coconut_tco_func = func
     tail_call_optimized_func.__module__ = _coconut.getattr(func, "__module__", None)
-    tail_call_optimized_func.__name__ = _coconut.getattr(func, "__name__", "<coconut tco function (pass --no-tco to remove)>")
-    tail_call_optimized_func.__qualname__ = _coconut.getattr(func, "__qualname__", tail_call_optimized_func.__name__)
+    tail_call_optimized_func.__name__ = _coconut.getattr(func, "__name__", None)
+    tail_call_optimized_func.__qualname__ = _coconut.getattr(func, "__qualname__", None)
     _coconut_tco_func_dict[_coconut.id(tail_call_optimized_func)] = _coconut.weakref.ref(tail_call_optimized_func)
     return tail_call_optimized_func
-def _coconut_igetitem(iterable, index):
-    obj_igetitem = _coconut.getattr(iterable, "__igetitem__", None)
-    if obj_igetitem is None:
-        obj_igetitem = _coconut.getattr(iterable, "__getitem__", None)
-    if obj_igetitem is not None:
+def _coconut_iter_getitem_special_case(iterable, start, stop, step):
+    iterable = _coconut.itertools.islice(iterable, start, None)
+    cache = _coconut.collections.deque(_coconut.itertools.islice(iterable, -stop), maxlen=-stop)
+    for index, item in _coconut.enumerate(iterable):
+        cached_item = cache.popleft()
+        if index % step == 0:
+            yield cached_item
+        cache.append(item)
+def _coconut_iter_getitem(iterable, index):
+    """Some code taken from more_itertools under the terms of its MIT license."""
+    obj_iter_getitem = _coconut.getattr(iterable, "__iter_getitem__", None)
+    if obj_iter_getitem is None:
+        obj_iter_getitem = _coconut.getattr(iterable, "__getitem__", None)
+    if obj_iter_getitem is not None:
         try:
-            result = obj_igetitem(index)
+            result = obj_iter_getitem(index)
         except _coconut.NotImplementedError:
             pass
         else:
@@ -315,16 +340,14 @@ def _coconut_igetitem(iterable, index):
     if not _coconut.isinstance(index, _coconut.slice):
         if index < 0:
             return _coconut.collections.deque(iterable, maxlen=-index)[0]
-        try:
-            return _coconut.next(_coconut.itertools.islice(iterable, index, index + 1))
-        except _coconut.StopIteration:
+        result = _coconut.next(_coconut.itertools.islice(iterable, index, index + 1), _coconut_sentinel)
+        if result is _coconut_sentinel:
             raise _coconut.IndexError("$[] index out of range")
-    if index.start is not None and index.start < 0 and (index.stop is None or index.stop < 0) and index.step is None:
-        queue = _coconut.collections.deque(iterable, maxlen=-index.start)
-        if index.stop is not None:
-            queue = _coconut.list(queue)[:index.stop - index.start]
-        return queue
-    if (index.start is None or index.start == 0) and index.stop is None and index.step is not None and index.step == -1:
+        return result
+    start, stop, step = index.start, index.stop, 1 if index.step is None else index.step
+    if step == 0:
+        raise _coconut.ValueError("slice step cannot be zero")
+    if start is None and stop is None and step == -1:
         obj_reversed = _coconut.getattr(iterable, "__reversed__", None)
         if obj_reversed is not None:
             try:
@@ -334,9 +357,57 @@ def _coconut_igetitem(iterable, index):
             else:
                 if result is not _coconut.NotImplemented:
                     return result
-    if (index.start is not None and index.start < 0) or (index.stop is not None and index.stop < 0) or (index.step is not None and index.step < 0):
-        return _coconut.list(iterable)[index]
-    return _coconut.itertools.islice(iterable, index.start, index.stop, index.step)
+    if step >= 0:
+        start = 0 if start is None else start
+        if start < 0:
+            cache = _coconut.collections.deque(_coconut.enumerate(iterable, 1), maxlen=-start)
+            len_iter = cache[-1][0] if cache else 0
+            i = _coconut.max(len_iter + start, 0)
+            if stop is None:
+                j = len_iter
+            elif stop >= 0:
+                j = _coconut.min(stop, len_iter)
+            else:
+                j = _coconut.max(len_iter + stop, 0)
+            n = j - i
+            if n <= 0:
+                return ()
+            if n < -start or step != 1:
+                cache = _coconut.itertools.islice(cache, 0, n, step)
+            return _coconut_map(_coconut.operator.itemgetter(1), cache)
+        elif stop is None or stop >= 0:
+            return _coconut.itertools.islice(iterable, start, stop, step)
+        else:
+            return _coconut_iter_getitem_special_case(iterable, start, stop, step)
+    else:
+        start = -1 if start is None else start
+        if stop is not None and stop < 0:
+            n = -stop - 1
+            cache = _coconut.collections.deque(_coconut.enumerate(iterable, 1), maxlen=n)
+            len_iter = cache[-1][0] if cache else 0
+            if start < 0:
+                i, j = start, stop
+            else:
+                i, j = _coconut.min(start - len_iter, -1), None
+            return _coconut_map(_coconut.operator.itemgetter(1), _coconut.tuple(cache)[i:j:step])
+        else:
+            if stop is not None:
+                m = stop + 1
+                iterable = _coconut.itertools.islice(iterable, m, None)
+            if start < 0:
+                i = start
+                n = None
+            elif stop is None:
+                i = None
+                n = start + 1
+            else:
+                i = None
+                n = start - stop
+            if n is not None:
+                if n <= 0:
+                    return ()
+                iterable = _coconut.itertools.islice(iterable, 0, n)
+            return _coconut.tuple(iterable)[i::step]
 class _coconut_base_compose(_coconut_base_hashable):
     __slots__ = ("func", "funcstars")
     def __init__(self, func, *funcstars):
@@ -387,16 +458,17 @@ def _coconut_back_dubstar_pipe(f, kws): return f(**kws)
 def _coconut_none_pipe(x, f): return None if x is None else f(x)
 def _coconut_none_star_pipe(xs, f): return None if xs is None else f(*xs)
 def _coconut_none_dubstar_pipe(kws, f): return None if kws is None else f(**kws)
-def _coconut_assert(cond, msg=None): assert cond, msg if msg is not None else "(assert) got falsey value " + _coconut.repr(cond)
+def _coconut_assert(cond, msg=None):
+    if not cond:
+        assert False, msg if msg is not None else "(assert) got falsey value " + _coconut.repr(cond)
 def _coconut_bool_and(a, b): return a and b
 def _coconut_bool_or(a, b): return a or b
-def _coconut_none_coalesce(a, b): return a if a is not None else b
-def _coconut_minus(a, *rest):
-    if not rest:
+def _coconut_none_coalesce(a, b): return b if a is None else a
+def _coconut_minus(a, b=_coconut_sentinel):
+    if b is _coconut_sentinel:
         return -a
-    for b in rest:
-        a = a - b
-    return a
+    return a - b
+def _coconut_comma_op(*args): return args
 @_coconut.functools.wraps(_coconut.itertools.tee)
 def tee(iterable, n=2):
     if n >= 0 and _coconut.isinstance(iterable, (_coconut.tuple, _coconut.frozenset)):
@@ -405,7 +477,7 @@ def tee(iterable, n=2):
         return (iterable,) + _coconut.tuple(_coconut.copy.copy(iterable) for _ in _coconut.range(n - 1))
     return _coconut.itertools.tee(iterable, n)
 class reiterable(_coconut_base_hashable):
-    """Allows an iterator to be iterated over multiple times."""
+    """Allow an iterator to be iterated over multiple times with the same results."""
     __slots__ = ("lock", "iter")
     def __new__(cls, iterable):
         if _coconut.isinstance(iterable, _coconut_reiterable):
@@ -421,7 +493,7 @@ class reiterable(_coconut_base_hashable):
     def __iter__(self):
         return _coconut.iter(self.get_new_iter())
     def __getitem__(self, index):
-        return _coconut_igetitem(self.get_new_iter(), index)
+        return _coconut_iter_getitem(self.get_new_iter(), index)
     def __reversed__(self):
         return _coconut_reversed(self.get_new_iter())
     def __len__(self):
@@ -436,14 +508,14 @@ class reiterable(_coconut_base_hashable):
         return _coconut_map(func, self)
 class scan(_coconut_base_hashable):
     """Reduce func over iterable, yielding intermediate results,
-    optionally starting from initializer."""
-    __slots__ = ("func", "iter", "initializer")
-    def __init__(self, function, iterable, initializer=_coconut_sentinel):
+    optionally starting from initial."""
+    __slots__ = ("func", "iter", "initial")
+    def __init__(self, function, iterable, initial=_coconut_sentinel):
         self.func = function
         self.iter = iterable
-        self.initializer = initializer
+        self.initial = initial
     def __iter__(self):
-        acc = self.initializer
+        acc = self.initial
         if acc is not _coconut_sentinel:
             yield acc
         for item in self.iter:
@@ -455,9 +527,9 @@ class scan(_coconut_base_hashable):
     def __len__(self):
         return _coconut.len(self.iter)
     def __repr__(self):
-        return "scan(%r, %r)" % (self.func, self.iter) if self.initializer is _coconut_sentinel else "scan(%r, %r, %r)" % (self.func, self.iter, self.initializer)
+        return "scan(%r, %s%s)" % (self.func, _coconut.repr(self.iter), "" if self.initial is _coconut_sentinel else ", " + _coconut.repr(self.initial))
     def __reduce__(self):
-        return (self.__class__, (self.func, self.iter, self.initializer))
+        return (self.__class__, (self.func, self.iter, self.initial))
     def __fmap__(self, func):
         return _coconut_map(func, self)
 class reversed(_coconut_base_hashable):
@@ -476,14 +548,14 @@ class reversed(_coconut_base_hashable):
         return _coconut.iter(_coconut.reversed(self.iter))
     def __getitem__(self, index):
         if _coconut.isinstance(index, _coconut.slice):
-            return _coconut_igetitem(self.iter, _coconut.slice(-(index.start + 1) if index.start is not None else None, -(index.stop + 1) if index.stop else None, -(index.step if index.step is not None else 1)))
-        return _coconut_igetitem(self.iter, -(index + 1))
+            return _coconut_iter_getitem(self.iter, _coconut.slice(-(index.start + 1) if index.start is not None else None, -(index.stop + 1) if index.stop else None, -(index.step if index.step is not None else 1)))
+        return _coconut_iter_getitem(self.iter, -(index + 1))
     def __reversed__(self):
         return self.iter
     def __len__(self):
         return _coconut.len(self.iter)
     def __repr__(self):
-        return "reversed(%r)" % (self.iter,)
+        return "reversed(%s)" % (_coconut.repr(self.iter),)
     def __reduce__(self):
         return (self.__class__, (self.iter,))
     def __contains__(self, elem):
@@ -538,8 +610,8 @@ class map(_coconut_base_hashable, _coconut.map):
         return new_map
     def __getitem__(self, index):
         if _coconut.isinstance(index, _coconut.slice):
-            return self.__class__(self.func, *(_coconut_igetitem(i, index) for i in self.iters))
-        return self.func(*(_coconut_igetitem(i, index) for i in self.iters))
+            return self.__class__(self.func, *(_coconut_iter_getitem(i, index) for i in self.iters))
+        return self.func(*(_coconut_iter_getitem(i, index) for i in self.iters))
     def __reversed__(self):
         return self.__class__(self.func, *(_coconut_reversed(i) for i in self.iters))
     def __len__(self):
@@ -612,8 +684,8 @@ class _coconut_base_parallel_concurrent_map(map):
     def __iter__(self):
         return _coconut.iter(self.get_list())
 class parallel_map(_coconut_base_parallel_concurrent_map):
-    """
-    Multi-process implementation of map. Requires arguments to be pickleable.
+    """Multi-process implementation of map. Requires arguments to be pickleable.
+
     For multiple sequential calls, use:
         with parallel_map.multiple_sequential_calls():
             ...
@@ -626,8 +698,9 @@ class parallel_map(_coconut_base_parallel_concurrent_map):
     def __repr__(self):
         return "parallel_" + _coconut_map.__repr__(self)
 class concurrent_map(_coconut_base_parallel_concurrent_map):
-    """
-    Multi-thread implementation of map. For multiple sequential calls, use:
+    """Multi-thread implementation of map.
+
+    For multiple sequential calls, use:
         with concurrent_map.multiple_sequential_calls():
             ...
     """
@@ -650,7 +723,7 @@ class filter(_coconut_base_hashable, _coconut.filter):
     def __reversed__(self):
         return self.__class__(self.func, _coconut_reversed(self.iter))
     def __repr__(self):
-        return "filter(%r, %r)" % (self.func, self.iter)
+        return "filter(%r, %s)" % (self.func, _coconut.repr(self.iter))
     def __reduce__(self):
         return (self.__class__, (self.func, self.iter))
     def __iter__(self):
@@ -670,8 +743,8 @@ class zip(_coconut_base_hashable, _coconut.zip):
         return new_zip
     def __getitem__(self, index):
         if _coconut.isinstance(index, _coconut.slice):
-            return self.__class__(*(_coconut_igetitem(i, index) for i in self.iters), strict=self.strict)
-        return _coconut.tuple(_coconut_igetitem(i, index) for i in self.iters)
+            return self.__class__(*(_coconut_iter_getitem(i, index) for i in self.iters), strict=self.strict)
+        return _coconut.tuple(_coconut_iter_getitem(i, index) for i in self.iters)
     def __reversed__(self):
         return self.__class__(*(_coconut_reversed(i) for i in self.iters), strict=self.strict)
     def __len__(self):
@@ -702,14 +775,14 @@ class zip_longest(zip):
     def __getitem__(self, index):
         if _coconut.isinstance(index, _coconut.slice):
             new_ind = _coconut.slice(index.start + self.__len__() if index.start is not None and index.start < 0 else index.start, index.stop + self.__len__() if index.stop is not None and index.stop < 0 else index.stop, index.step)
-            return self.__class__(*(_coconut_igetitem(i, new_ind) for i in self.iters))
+            return self.__class__(*(_coconut_iter_getitem(i, new_ind) for i in self.iters))
         if index < 0:
             index += self.__len__()
         result = []
         got_non_default = False
         for it in self.iters:
             try:
-                result.append(_coconut_igetitem(it, index))
+                result.append(_coconut_iter_getitem(it, index))
             except _coconut.IndexError:
                 result.append(self.fillvalue)
             else:
@@ -720,7 +793,7 @@ class zip_longest(zip):
     def __len__(self):
         return _coconut.max(_coconut.len(i) for i in self.iters)
     def __repr__(self):
-        return "zip_longest(%s, fillvalue=%s)" % (", ".join((_coconut.repr(i) for i in self.iters)), self.fillvalue)
+        return "zip_longest(%s, fillvalue=%s)" % (", ".join((_coconut.repr(i) for i in self.iters)), _coconut.repr(self.fillvalue))
     def __reduce__(self):
         return (self.__class__, self.iters, self.fillvalue)
     def __setstate__(self, fillvalue):
@@ -738,12 +811,12 @@ class enumerate(_coconut_base_hashable, _coconut.enumerate):
         return new_enumerate
     def __getitem__(self, index):
         if _coconut.isinstance(index, _coconut.slice):
-            return self.__class__(_coconut_igetitem(self.iter, index), self.start + (0 if index.start is None else index.start if index.start >= 0 else _coconut.len(self.iter) + index.start))
-        return (self.start + index, _coconut_igetitem(self.iter, index))
+            return self.__class__(_coconut_iter_getitem(self.iter, index), self.start + (0 if index.start is None else index.start if index.start >= 0 else _coconut.len(self.iter) + index.start))
+        return (self.start + index, _coconut_iter_getitem(self.iter, index))
     def __len__(self):
         return _coconut.len(self.iter)
     def __repr__(self):
-        return "enumerate(%r, %r)" % (self.iter, self.start)
+        return "enumerate(%s, %r)" % (_coconut.repr(self.iter), self.start)
     def __reduce__(self):
         return (self.__class__, (self.iter, self.start))
     def __iter__(self):
@@ -752,7 +825,9 @@ class enumerate(_coconut_base_hashable, _coconut.enumerate):
         return _coconut_map(func, self)
 class count(_coconut_base_hashable):
     """count(start, step) returns an infinite iterator starting at start and increasing by step.
-    If step is set to 0, count will infinitely repeat its first argument."""
+
+    If step is set to 0, count will infinitely repeat its first argument.
+    """
     __slots__ = ("start", "step")
     def __init__(self, start=0, step=1):
         self.start = start
@@ -798,7 +873,7 @@ class count(_coconut_base_hashable):
             return self
         raise _coconut.TypeError(_coconut.repr(self) + " object is not reversible")
     def __repr__(self):
-        return "count(%r, %r)" % (self.start, self.step)
+        return "count(%s, %s)" % (_coconut.repr(self.start), _coconut.repr(self.step))
     def __reduce__(self):
         return (self.__class__, (self.start, self.step))
     def __copy__(self):
@@ -807,7 +882,9 @@ class count(_coconut_base_hashable):
         return _coconut_map(func, self)
 class groupsof(_coconut_base_hashable):
     """groupsof(n, iterable) splits iterable into groups of size n.
-    If the length of the iterable is not divisible by n, the last group may be of size < n."""
+
+    If the length of the iterable is not divisible by n, the last group may be of size < n.
+    """
     __slots__ = ("group_size", "iter")
     def __init__(self, n, iterable):
         self.iter = iterable
@@ -831,7 +908,7 @@ class groupsof(_coconut_base_hashable):
             if group:
                 yield _coconut.tuple(group)
     def __len__(self):
-        return _coconut.len(self.iter)
+        return _coconut.int(_coconut.math.ceil(_coconut.len(self.iter) / self.group_size))
     def __repr__(self):
         return "groupsof(%r)" % (self.iter,)
     def __reduce__(self):
@@ -839,7 +916,7 @@ class groupsof(_coconut_base_hashable):
     def __fmap__(self, func):
         return _coconut_map(func, self)
 class recursive_iterator(_coconut_base_hashable):
-    """Decorator that optimizes a function for iterator recursion."""
+    """Decorator that optimizes a recursive function that returns an iterator (e.g. a recursive generator)."""
     __slots__ = ("func", "tee_store", "backup_tee_store")
     def __init__(self, func):
         self.func = func
@@ -875,7 +952,7 @@ class recursive_iterator(_coconut_base_hashable):
             self.tee_store[key], to_return = _coconut_tee(it)
         return to_return
     def __repr__(self):
-        return "@recursive_iterator(%s)" % (_coconut.repr(self.func),)
+        return "@recursive_iterator(%r)" % (self.func,)
     def __reduce__(self):
         return (self.__class__, (self.func,))
     def __get__(self, obj, objtype=None):
@@ -952,7 +1029,7 @@ class _coconut_base_pattern_func(_coconut_base_hashable):
                 pass
         return _coconut_tail_call(self.patterns[-1], *args, **kwargs)
     def __repr__(self):
-        return "addpattern(%s)(*%s)" % (_coconut.repr(self.patterns[0]), _coconut.repr(self.patterns[1:]))
+        return "addpattern(%r)(*%r)" % (self.patterns[0], self.patterns[1:])
     def __reduce__(self):
         return (self.__class__, _coconut.tuple(self.patterns))
     def __get__(self, obj, objtype=None):
@@ -966,8 +1043,7 @@ def _coconut_mark_as_match(base_func):
     base_func._coconut_is_match = True
     return base_func
 def addpattern(base_func, **kwargs):
-    """Decorator to add a new case to a pattern-matching function,
-    where the new case is checked last."""
+    """Decorator to add a new case to a pattern-matching function (where the new case is checked last)."""
     allow_any_func = kwargs.pop("allow_any_func", False)
     if not allow_any_func and not _coconut.getattr(base_func, "_coconut_is_match", False):
         _coconut.warnings.warn("Possible misuse of addpattern with non-pattern-matching function " + _coconut.repr(base_func) + " (pass allow_any_func=True to dismiss)", stacklevel=2)
@@ -982,10 +1058,10 @@ class _coconut_partial(_coconut_base_hashable):
     __slots__ = ("func", "_argdict", "_arglen", "_stargs", "keywords")
     if hasattr(_coconut.functools.partial, "__doc__"):
         __doc__ = _coconut.functools.partial.__doc__
-    def __init__(self, func, argdict, arglen, *args, **kwargs):
-        self.func = func
-        self._argdict = argdict
-        self._arglen = arglen
+    def __init__(self, _coconut_func, _coconut_argdict, _coconut_arglen, *args, **kwargs):
+        self.func = _coconut_func
+        self._argdict = _coconut_argdict
+        self._arglen = _coconut_arglen
         self._stargs = args
         self.keywords = kwargs
     def __reduce__(self):
@@ -1019,9 +1095,11 @@ class _coconut_partial(_coconut_base_hashable):
                 args.append("?")
         for arg in self._stargs:
             args.append(_coconut.repr(arg))
-        return "%s$(%s)" % (_coconut.repr(self.func), ", ".join(args))
+        for k, v in self.keywords.items():
+            args.append(k + "=" + _coconut.repr(v))
+        return "%r$(%s)" % (self.func, ", ".join(args))
 def consume(iterable, keep_last=0):
-    """consume(iterable, keep_last) fully exhausts iterable and return the last keep_last elements."""
+    """consume(iterable, keep_last) fully exhausts iterable and returns the last keep_last elements."""
     return _coconut.collections.deque(iterable, maxlen=keep_last)
 class starmap(_coconut_base_hashable, _coconut.itertools.starmap):
     __slots__ = ("func", "iter")
@@ -1034,8 +1112,8 @@ class starmap(_coconut_base_hashable, _coconut.itertools.starmap):
         return new_map
     def __getitem__(self, index):
         if _coconut.isinstance(index, _coconut.slice):
-            return self.__class__(self.func, _coconut_igetitem(self.iter, index))
-        return self.func(*_coconut_igetitem(self.iter, index))
+            return self.__class__(self.func, _coconut_iter_getitem(self.iter, index))
+        return self.func(*_coconut_iter_getitem(self.iter, index))
     def __reversed__(self):
         return self.__class__(self.func, *_coconut_reversed(self.iter))
     def __len__(self):
@@ -1062,7 +1140,9 @@ def datamaker(*args, **kwargs):
     raise _coconut.NameError("deprecated feature 'datamaker' disabled by --strict compilation; use 'makedata' instead")
 def fmap(func, obj):
     """fmap(func, obj) creates a copy of obj with func applied to its contents.
-    Override by defining obj.__fmap__(func). For numpy arrays, uses np.vectorize."""
+
+    Override by defining obj.__fmap__(func). For numpy arrays, uses np.vectorize.
+    """
     obj_fmap = _coconut.getattr(obj, "__fmap__", None)
     if obj_fmap is not None:
         try:
@@ -1072,13 +1152,12 @@ def fmap(func, obj):
         else:
             if result is not _coconut.NotImplemented:
                 return result
-    if obj.__class__.__module__ in ("numpy", "pandas"):
-        from numpy import vectorize
-        return vectorize(func)(obj)
+    if obj.__class__.__module__ in ('numpy', 'pandas'):
+        return _coconut.numpy.vectorize(func)(obj)
     return _coconut_makedata(obj.__class__, *(_coconut_starmap(func, obj.items()) if _coconut.isinstance(obj, _coconut.abc.Mapping) else _coconut_map(func, obj)))
 def memoize(maxsize=None, *args, **kwargs):
-    """Decorator that memoizes a function,
-    preventing it from being recomputed if it is called multiple times with the same arguments."""
+    """Decorator that memoizes a function, preventing it from being recomputed
+    if it is called multiple times with the same arguments."""
     return _coconut.functools.lru_cache(maxsize, *args, **kwargs)
 def _coconut_call_set_names(cls):
     if _coconut_sys.version_info < (3, 6):
@@ -1110,4 +1189,204 @@ def reveal_locals():
     """Special function to get MyPy to print the type of the current locals.
     At runtime, reveal_locals always returns None."""
     pass
+def _coconut_handle_cls_kwargs(**kwargs):
+    """Some code taken from six under the terms of its MIT license."""
+    metaclass = kwargs.pop("metaclass", None)
+    if kwargs and metaclass is None:
+        raise _coconut.TypeError("unexpected keyword argument(s) in class definition: %r" % (kwargs,))
+    def coconut_handle_cls_kwargs_wrapper(cls):
+        if metaclass is None:
+            return cls
+        orig_vars = cls.__dict__.copy()
+        slots = orig_vars.get("__slots__")
+        if slots is not None:
+            if _coconut.isinstance(slots, _coconut.str):
+                slots = [slots]
+            for slots_var in slots:
+                orig_vars.pop(slots_var)
+        orig_vars.pop("__dict__", None)
+        orig_vars.pop("__weakref__", None)
+        if _coconut.hasattr(cls, "__qualname__"):
+            orig_vars["__qualname__"] = cls.__qualname__
+        return metaclass(cls.__name__, cls.__bases__, orig_vars, **kwargs)
+    return coconut_handle_cls_kwargs_wrapper
+def _coconut_handle_cls_stargs(*args):
+    temp_names = ["_coconut_base_cls_%s" % (i,) for i in _coconut.range(_coconut.len(args))]
+    ns = _coconut.dict(_coconut.zip(temp_names, args))
+    _coconut_exec("class _coconut_cls_stargs_base(" + ", ".join(temp_names) + "): pass", ns)
+    return ns["_coconut_cls_stargs_base"]
+def _coconut_dict_merge(*dicts, **kwargs):
+    for_func = kwargs.pop("for_func", False)
+    assert not kwargs, "error with internal Coconut function _coconut_dict_merge (you should report this at https://github.com/evhub/coconut/issues/new)"
+    newdict = {}
+    prevlen = 0
+    for d in dicts:
+        newdict.update(d)
+        if for_func:
+            if _coconut.len(newdict) != prevlen + _coconut.len(d):
+                raise _coconut.TypeError("multiple values for the same keyword argument")
+            prevlen = _coconut.len(newdict)
+    return newdict
+def ident(x, **kwargs):
+    """The identity function. Generally equivalent to x -> x. Useful in point-free programming.
+    Accepts one keyword-only argument, side_effect, which specifies a function to call on the argument before it is returned."""
+    side_effect = kwargs.pop("side_effect", None)
+    if kwargs:
+        raise _coconut.TypeError("ident() got unexpected keyword arguments " + _coconut.repr(kwargs))
+    if side_effect is not None:
+        side_effect(x)
+    return x
+def of(_coconut_f, *args, **kwargs):
+    """Function application operator function.
+
+    Equivalent to:
+        def of(f, *args, **kwargs) = f(*args, **kwargs).
+    """
+    return _coconut_f(*args, **kwargs)
+class flip(_coconut_base_hashable):
+    """Given a function, return a new function with inverse argument order.
+    If nargs is passed, only the first nargs arguments are reversed."""
+    __slots__ = ("func", "nargs")
+    def __init__(self, func, nargs=None):
+        self.func = func
+        self.nargs = nargs
+    def __reduce__(self):
+        return (self.__class__, (self.func, self.nargs))
+    def __call__(self, *args, **kwargs):
+        return self.func(*args[::-1], **kwargs) if self.nargs is None else self.func(*(args[self.nargs-1::-1] + args[self.nargs:]), **kwargs)
+    def __repr__(self):
+        return "flip(%r%s)" % (self.func, "" if self.nargs is None else ", " + _coconut.repr(self.nargs))
+class const(_coconut_base_hashable):
+    """Create a function that, whatever its arguments, just returns the given value."""
+    __slots__ = ("value",)
+    def __init__(self, value):
+        self.value = value
+    def __reduce__(self):
+        return (self.__class__, (self.value,))
+    def __call__(self, *args, **kwargs):
+        return self.value
+    def __repr__(self):
+        return "const(%s)" % (_coconut.repr(self.value),)
+class _coconut_lifted(_coconut_base_hashable):
+    __slots__ = ("func", "func_args", "func_kwargs")
+    def __init__(self, _coconut_func, *func_args, **func_kwargs):
+        self.func = _coconut_func
+        self.func_args = func_args
+        self.func_kwargs = func_kwargs
+    def __reduce__(self):
+        return (self.__class__, (self.func,) + self.func_args, self.func_kwargs)
+    def __setstate__(self, func_kwargs):
+        self.func_kwargs = func_kwargs
+    def __call__(self, *args, **kwargs):
+        return self.func(*(g(*args, **kwargs) for g in self.func_args), **_coconut.dict((k, h(*args, **kwargs)) for k, h in self.func_kwargs.items()))
+    def __repr__(self):
+        return "lift(%r)(%s%s)" % (self.func, ", ".join(_coconut.repr(g) for g in self.func_args), ", ".join(k + "=" + _coconut.repr(h) for k, h in self.func_kwargs.items()))
+class lift(_coconut_base_hashable):
+    """Lifts a function up so that all of its arguments are functions.
+
+    For a binary function f(x, y) and two unary functions g(z) and h(z), lift works as the S' combinator:
+        lift(f)(g, h)(z) == f(g(z), h(z))
+
+    In general, lift is requivalent to:
+        def lift(f) = ((*func_args, **func_kwargs) -> (*args, **kwargs) ->
+            f(*(g(*args, **kwargs) for g in func_args), **{k: h(*args, **kwargs) for k, h in func_kwargs.items()}))
+
+    lift also supports a shortcut form such that lift(f, *func_args, **func_kwargs) is equivalent to lift(f)(*func_args, **func_kwargs).
+    """
+    __slots__ = ("func",)
+    def __new__(cls, func, *func_args, **func_kwargs):
+        self = _coconut.object.__new__(cls)
+        self.func = func
+        if func_args or func_kwargs:
+            self = self(*func_args, **func_kwargs)
+        return self
+    def __reduce__(self):
+        return (self.__class__, (self.func,))
+    def __call__(self, *func_args, **func_kwargs):
+        return _coconut_lifted(self.func, *func_args, **func_kwargs)
+    def __repr__(self):
+        return "lift(%r)" % (self.func,)
+def all_equal(iterable):
+    """For a given iterable, check whether all elements in that iterable are equal to each other.
+
+    Assumes transitivity and 'x != y' being equivalent to 'not (x == y)'.
+    """
+    first_item = _coconut_sentinel
+    for item in iterable:
+        if first_item is _coconut_sentinel:
+            first_item = item
+        elif first_item != item:
+            return False
+    return True
+def match_if(obj, predicate):
+    """Meant to be used in infix pattern-matching expressions to match the left-hand side only if the predicate on the right-hand side holds.
+
+    For example:
+        a `match_if` predicate or b = obj
+
+    The actual definition of match_if is extremely simple:
+        def match_if(obj, predicate) = predicate(obj)
+    """
+    return predicate(obj)
+def collectby(key_func, iterable, value_func=None, reduce_func=None):
+    """Collect the items in iterable into a dictionary of lists keyed by key_func(item).
+
+    if value_func is passed, collect value_func(item) into each list instead of item.
+
+    If reduce_func is passed, instead of collecting the items into lists, reduce over
+    the items of each key with reduce_func, effectively implementing a MapReduce operation.
+    """
+    collection = _coconut.collections.defaultdict(_coconut.list) if reduce_func is None else {}
+    for item in iterable:
+        key = key_func(item)
+        if value_func is not None:
+            item = value_func(item)
+        if reduce_func is None:
+            collection[key].append(item)
+        else:
+            old_item = collection.get(key, _coconut_sentinel)
+            if old_item is not _coconut_sentinel:
+                item = reduce_func(old_item, item)
+            collection[key] = item
+    return collection
+def _namedtuple_of(**kwargs):
+    """Construct an anonymous namedtuple of the given keyword arguments."""
+    if _coconut_sys.version_info < (3, 6):
+        raise _coconut.RuntimeError("_namedtuple_of is not available on Python < 3.6 (use anonymous namedtuple literals instead)")
+    else:
+        return _coconut.collections.namedtuple("_namedtuple_of", kwargs.keys())(*kwargs.values())
+def _coconut_ndim(arr):
+    if arr.__class__.__module__ in ('numpy', 'pandas') and _coconut.isinstance(arr, _coconut.numpy.ndarray):
+        return arr.ndim
+    if not _coconut.isinstance(arr, _coconut.abc.Sequence):
+        return 0
+    if _coconut.len(arr) == 0:
+        return 1
+    arr_dim = 1
+    inner_arr = arr[0]
+    while _coconut.isinstance(inner_arr, _coconut.abc.Sequence):
+        arr_dim += 1
+        if _coconut.len(inner_arr) < 1:
+            break
+        inner_arr = inner_arr[0]
+    return arr_dim
+def _coconut_expand_arr(arr, new_dims):
+    if arr.__class__.__module__ in ('numpy', 'pandas') and _coconut.isinstance(arr, _coconut.numpy.ndarray):
+        return arr.reshape((1,) * new_dims + arr.shape)
+    for _ in _coconut.range(new_dims):
+        arr = [arr]
+    return arr
+def _coconut_concatenate(arrs, axis):
+    if _coconut.any(a.__class__.__module__ in ('numpy', 'pandas') for a in arrs):
+        return _coconut.numpy.concatenate(arrs, axis)
+    if not axis:
+        return _coconut.list(_coconut.itertools.chain.from_iterable(arrs))
+    return [_coconut_concatenate(rows, axis - 1) for rows in _coconut.zip(*arrs)]
+def _coconut_multi_dim_arr(arrs, dim):
+    arr_dims = [_coconut_ndim(a) for a in arrs]
+    arrs = [_coconut_expand_arr(a, dim - d) if d < dim else a for a, d in _coconut.zip(arrs, arr_dims)]
+    arr_dims.append(dim)
+    max_arr_dim = _coconut.max(arr_dims)
+    return _coconut_concatenate(arrs, max_arr_dim - dim)
+_coconut_self_match_types = (bool, bytearray, bytes, dict, float, frozenset, int, list, set, str, tuple)
 _coconut_MatchError, _coconut_count, _coconut_enumerate, _coconut_filter, _coconut_makedata, _coconut_map, _coconut_reiterable, _coconut_reversed, _coconut_starmap, _coconut_tee, _coconut_zip, TYPE_CHECKING, reduce, takewhile, dropwhile = MatchError, count, enumerate, filter, makedata, map, reiterable, reversed, starmap, tee, zip, False, _coconut.functools.reduce, _coconut.itertools.takewhile, _coconut.itertools.dropwhile
