@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# __coconut_hash__ = 0x48c9e0b1
+# __coconut_hash__ = 0xac8318a5
 
-# Compiled with Coconut version 1.5.0-post_dev74 [Fish License]
+# Compiled with Coconut version 2.0.0-a_dev36 [How Not to Be Seen]
 
 """
 The backend and algorithm registries.
@@ -14,7 +14,7 @@ from __future__ import print_function, absolute_import, unicode_literals, divisi
 import sys as _coconut_sys, os as _coconut_os
 _coconut_file_dir = _coconut_os.path.dirname(_coconut_os.path.abspath(__file__))
 _coconut_cached_module = _coconut_sys.modules.get(str("__coconut__"))
-if _coconut_cached_module is not None and _coconut_os.path.dirname(_coconut_cached_module.__file__) != _coconut_file_dir:
+if _coconut_cached_module is not None and _coconut_os.path.dirname(_coconut_cached_module.__file__) != _coconut_file_dir:  # type: ignore
     del _coconut_sys.modules[str("__coconut__")]
 _coconut_sys.path.insert(0, _coconut_file_dir)
 _coconut_module_name = _coconut_os.path.splitext(_coconut_os.path.basename(_coconut_file_dir))[0]
@@ -32,7 +32,7 @@ if _coconut_module_name and _coconut_module_name[0].isalpha() and all(c.isalpha(
                     _coconut_v_type.__module__ = _coconut_full_module_name
     _coconut_sys.modules[_coconut_full_module_name] = _coconut__coconut__
 from __coconut__ import *
-from __coconut__ import _coconut_call_set_names, _coconut, _coconut_MatchError, _coconut_igetitem, _coconut_base_compose, _coconut_forward_compose, _coconut_back_compose, _coconut_forward_star_compose, _coconut_back_star_compose, _coconut_forward_dubstar_compose, _coconut_back_dubstar_compose, _coconut_pipe, _coconut_star_pipe, _coconut_dubstar_pipe, _coconut_back_pipe, _coconut_back_star_pipe, _coconut_back_dubstar_pipe, _coconut_none_pipe, _coconut_none_star_pipe, _coconut_none_dubstar_pipe, _coconut_bool_and, _coconut_bool_or, _coconut_none_coalesce, _coconut_minus, _coconut_map, _coconut_partial, _coconut_get_function_match_error, _coconut_base_pattern_func, _coconut_addpattern, _coconut_sentinel, _coconut_assert, _coconut_mark_as_match, _coconut_reiterable
+from __coconut__ import _coconut_call_set_names, _coconut_handle_cls_kwargs, _coconut_handle_cls_stargs, _namedtuple_of, _coconut, _coconut_MatchError, _coconut_iter_getitem, _coconut_base_compose, _coconut_forward_compose, _coconut_back_compose, _coconut_forward_star_compose, _coconut_back_star_compose, _coconut_forward_dubstar_compose, _coconut_back_dubstar_compose, _coconut_pipe, _coconut_star_pipe, _coconut_dubstar_pipe, _coconut_back_pipe, _coconut_back_star_pipe, _coconut_back_dubstar_pipe, _coconut_none_pipe, _coconut_none_star_pipe, _coconut_none_dubstar_pipe, _coconut_bool_and, _coconut_bool_or, _coconut_none_coalesce, _coconut_minus, _coconut_map, _coconut_partial, _coconut_get_function_match_error, _coconut_base_pattern_func, _coconut_addpattern, _coconut_sentinel, _coconut_assert, _coconut_mark_as_match, _coconut_reiterable, _coconut_self_match_types, _coconut_dict_merge, _coconut_exec, _coconut_comma_op, _coconut_multi_dim_arr
 _coconut_sys.path.pop(0)
 
 # Compiled Coconut: -----------------------------------------------------------
@@ -51,19 +51,25 @@ class Registry(_coconut.object):
         self.aliases = ({} if aliases is None else aliases)
         self.no_conflict_registries = []
 
+
     def shouldnt_conflict_with(self, registry):
         """Add the given registry to the no conflict registries."""
         self.no_conflict_registries.append(registry)
 
+
     def __getitem__(self, name):
         name = self.aliases.get(name, name)
         _coconut_match_to_0 = self.registered
         _coconut_match_check_0 = False
+        _coconut_match_set_name_value = _coconut_sentinel
         if _coconut.isinstance(_coconut_match_to_0, _coconut.abc.Mapping):
             _coconut_match_temp_0 = _coconut_match_to_0.get(name, _coconut_sentinel)
             if _coconut_match_temp_0 is not _coconut_sentinel:
-                value = _coconut_match_temp_0
+                _coconut_match_set_name_value = _coconut_match_temp_0
                 _coconut_match_check_0 = True
+        if _coconut_match_check_0:
+            if _coconut_match_set_name_value is not _coconut_sentinel:
+                value = _coconut_match_set_name_value
         if _coconut_match_check_0:
             return value
         else:
@@ -76,6 +82,7 @@ class Registry(_coconut.object):
                 valid_names = ", ".join((repr(name) for name in self))
                 raise ValueError("unknown {_coconut_format_0}: {_coconut_format_1} (valid {_coconut_format_2}s: {_coconut_format_3})".format(_coconut_format_0=(self.obj_name), _coconut_format_1=(name), _coconut_format_2=(self.obj_name), _coconut_format_3=(valid_names)))
 
+
     def get(self, name, default=None):
         """Attempt to __getitem__ else default."""
         try:
@@ -83,16 +90,21 @@ class Registry(_coconut.object):
         except (ValueError, TypeError):
             return default
 
+
     def register(self, name, value, replace=False):
         """Register value under the given name."""
         if not replace:
             _coconut_match_to_1 = self.registered
             _coconut_match_check_1 = False
+            _coconut_match_set_name_stored_val = _coconut_sentinel
             if _coconut.isinstance(_coconut_match_to_1, _coconut.abc.Mapping):
-                _coconut_match_temp_0 = _coconut_match_to_1.get(name, _coconut_sentinel)
-                if _coconut_match_temp_0 is not _coconut_sentinel:
-                    stored_val = _coconut_match_temp_0
+                _coconut_match_temp_1 = _coconut_match_to_1.get(name, _coconut_sentinel)
+                if _coconut_match_temp_1 is not _coconut_sentinel:
+                    _coconut_match_set_name_stored_val = _coconut_match_temp_1
                     _coconut_match_check_1 = True
+            if _coconut_match_check_1:
+                if _coconut_match_set_name_stored_val is not _coconut_sentinel:
+                    stored_val = _coconut_match_set_name_stored_val
             if _coconut_match_check_1:
                 if stored_val == value:
                     return
@@ -105,16 +117,21 @@ class Registry(_coconut.object):
                 raise ValueError("cannot register name with conflicting {_coconut_format_0}: {_coconut_format_1}".format(_coconut_format_0=(registry.obj_name), _coconut_format_1=(name)))
         self.registered[name] = value
 
+
     def register_alias(self, name, alias, replace=False):
         """Register an alias for the given name."""
         if not replace:
             _coconut_match_to_2 = self.aliases
             _coconut_match_check_2 = False
+            _coconut_match_set_name_stored_alias = _coconut_sentinel
             if _coconut.isinstance(_coconut_match_to_2, _coconut.abc.Mapping):
-                _coconut_match_temp_0 = _coconut_match_to_2.get(name, _coconut_sentinel)
-                if _coconut_match_temp_0 is not _coconut_sentinel:
-                    stored_alias = _coconut_match_temp_0
+                _coconut_match_temp_2 = _coconut_match_to_2.get(name, _coconut_sentinel)
+                if _coconut_match_temp_2 is not _coconut_sentinel:
+                    _coconut_match_set_name_stored_alias = _coconut_match_temp_2
                     _coconut_match_check_2 = True
+            if _coconut_match_check_2:
+                if _coconut_match_set_name_stored_alias is not _coconut_sentinel:
+                    stored_alias = _coconut_match_set_name_stored_alias
             if _coconut_match_check_2:
                 if stored_alias == alias:
                     return
@@ -127,6 +144,7 @@ class Registry(_coconut.object):
                 raise ValueError("cannot register alias with conflicting {_coconut_format_0}: {_coconut_format_1}".format(_coconut_format_0=(registry.obj_name), _coconut_format_1=(alias)))
         self.aliases[alias] = name
 
+
     def run_gen(self, name):
         """Run the generator for the given name."""
         value = self.generators[name]()
@@ -135,6 +153,7 @@ class Registry(_coconut.object):
         del self.generators[name]
         return self.registered[name]
 
+
     def __iter__(self):
         _coconut_yield_from_1 = _coconut.iter(self.registered)
         while True:
@@ -164,14 +183,17 @@ class Registry(_coconut.object):
 
         _coconut_yield_from_4
 
+
     def __contains__(self, name):
         return name in self.registered or name in self.generators or name in self.aliases
 
+
     def run_all_gens(self):
         """Run all generators."""
         for name in self.generators:
             self.run_gen(name)
 
+
     def items(self):
         """Get all items in the registry as (name, value) pairs."""
         self.run_all_gens()
@@ -185,6 +207,7 @@ class Registry(_coconut.object):
 
         _coconut_yield_from_6
 
+
     def asdict(self):
         """Convert registry to dictionary."""
         self.run_all_gens()
@@ -193,6 +216,7 @@ class Registry(_coconut.object):
 
 # Registries:
 
+
 _coconut_call_set_names(Registry)
 backend_registry = Registry("backend")
 
